package com.zehong.system.mapper;

import java.util.List;
import java.util.Map;

import com.zehong.system.domain.TRectifyGroupMemberInfo;

/**
 * 整改组内成员信息Mapper接口
 * 
 * @author zehong
 * @date 2026-07-16
 */
public interface TRectifyGroupMemberInfoMapper 
{
    /**
     * 查询整改组内成员信息
     * 
     * @param memberId 整改组内成员信息ID
     * @return 整改组内成员信息
     */
    public TRectifyGroupMemberInfo selectTRectifyGroupMemberInfoById(Long memberId);

    /**
     * 查询整改组内成员信息列表
     * 
     * @param tRectifyGroupMemberInfo 整改组内成员信息
     * @return 整改组内成员信息集合
     */
    public List<TRectifyGroupMemberInfo> selectTRectifyGroupMemberInfoList(TRectifyGroupMemberInfo tRectifyGroupMemberInfo);

    /**
     * 新增整改组内成员信息
     * 
     * @param tRectifyGroupMemberInfo 整改组内成员信息
     * @return 结果
     */
    public int insertTRectifyGroupMemberInfo(TRectifyGroupMemberInfo tRectifyGroupMemberInfo);

    /**
     * 修改整改组内成员信息
     * 
     * @param tRectifyGroupMemberInfo 整改组内成员信息
     * @return 结果
     */
    public int updateTRectifyGroupMemberInfo(TRectifyGroupMemberInfo tRectifyGroupMemberInfo);

    /**
     * 删除整改组内成员信息
     * 
     * @param memberId 整改组内成员信息ID
     * @return 结果
     */
    public int deleteTRectifyGroupMemberInfoById(Long memberId);

    /**
     * 批量删除整改组内成员信息
     * 
     * @param memberIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTRectifyGroupMemberInfoByIds(Long[] memberIds);

    /**
     * 获取整改人员人员信息
     * @return
     */
    List<Map<String,Object>> selectRectifyUserByPostCode(Map<String,Object> map);

    int deleteTRectifyGroupMemberInfoByGroupId(Long groupId);
}
